<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:j="http://www.oecd-nea.org/janis-import-log" exclude-result-prefixes="j">
    <xsl:output 
        method="html" 
        indent="yes" 
        encoding="UTF-8" 
        doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
        doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

  <!--
    JANIS Import Log
  -->

  <xsl:decimal-format decimal-separator="." grouping-separator="," />

  <xsl:key name="list_exceptions1" match="exception" use="concat(@class,'|',@msg1)" />
  <xsl:key name="list_exceptions2" match="exception" use="concat(@class,'|',@msg1,'|',@msg2)" />
  <xsl:key name="list_warnings1" match="warning" use="@msg1" />
  <xsl:key name="list_warnings2" match="warning" use="concat(@msg1,'|',@msg2)" />

  <xsl:template match="/">
    <html>
      <head>
        <title>JANIS Import Log</title>
        <style type="text/css">
          .bannercell { 
            border: 0px; padding: 0px; 
          } 
          body { 
            margin: 0; 
            font:normal 100% arial,helvetica,sanserif; 
            background-color:#FFFFFF; 
            color:#000000; 
          } 
          .hiddenlink { 
            color: black; 
            text-decoration: none; 
          }
          
          table.status { 
            font:bold 80% arial,helvetica,sanserif; 
            background-color:#525D76; 
            color:#ffffff; 
          } 
          table.log tr td, tr th { 
            font-size: 80%; 
          }
          .error { 
            color:white; 
            font:bold; 
            background-color: #FF0000; 
          } 
          .warn { 
            color:brown; 
            background-color: #FFFF00; 
          } 
          .info { color:gray; }
          .debug { color:gray; } 
          .a td { background: #efefef; } 
          .b td { background: #fff; }

          .red { background: #ff5555; } 
          .lightred { background: #ffcccc; } 
          .yellow{ background: #ffff55; } 
          .lightyellow { background: #ffffcc; }
          .green { background: #55ff55; } 
          .lightgreen { background: #ccffcc; }

          th, td { text-align: left; vertical-align: top; } 
          th { background: #ccc; color: black; } 
          table, th, td { border: none }
           
          .h td { 
            font:bold 120% arial,helvetica,sanserif; 
            text-align: center; 
            background: #525D76; 
            color: white; 
            text-decoration: none; 
            padding: 6px; 
            margin-right: 2px; 
            margin-left: 2px; 
            margin-top: 0; 
            margin-bottom: 0; 
          } 
          
          h3 { 
            font:bold 80% arial,helvetica,sanserif; 
            background: #525D76; color: white; 
            text-decoration: none; 
            padding: 5px; 
            margin-right: 2px; 
            margin-left: 2px;
             margin-bottom: 0; 
          } 
          .trace { 
            font: 70% arial,helvetica,sanserif; 
            margin-left: 20px; 
          }
          
          span.ref {
            white-space: nowrap; display: inline-block;
          }
          
          .popup {
              position: absolute;
              visibility: hidden;
              width: 600px;
              left: 20px;
              background-color: #FFFAD5;
              border: 1px solid #000;
              padding: 10px;
          }
          
          .popup .small {
              font-size: 8pt;
          }
          
          .popup .stacktrace {
              font-size: 8pt;
              white-space: pre;
          }
        </style>
        <script type="text/javascript">
            function toggleVisible(id) {
                obj = this.document.getElementById(id);
                if (obj.style.visibility == 'visible') {
                    obj.style.visibility = 'hidden';
                } else {
                    obj.style.visibility = 'visible';
                }
            }
        </script>
      </head>
      <body>
        <table border="0" width="100%">
          <tr><td><hr noshade="noshade" size="1" /></td></tr>
        </table>

        <!-- title -->
        <table border="1" cellspacing="0" cellpadding="0" width="100%" style="font-size:120%">
          <tr class="h">
            <td>JANIS Import Log<br />
            <span style="font-size:50%"><xsl:value-of select="/importlog/@timestamp" /></span></td>
          </tr>
        </table>

        <xsl:apply-templates select="importlog" />

        <!-- footer -->
        <table width="100%">
          <tr><td><hr noshade="noshade" size="1" /></td></tr>
          <tr>
            <td>
              <div align="center">
                <font color="#525D76" size="-1">
                  <em>JANIS Import Log</em> - 
                  <xsl:value-of select="/importlog/@timestamp" />
                </font>
              </div>
            </td>
          </tr>
        </table>
      </body>
    </html>
  </xsl:template>


  <xsl:variable name="warnings_count" select="count(/importlog/warning)" />
  <xsl:variable name="exceptions_count" select="count(/importlog/exception)" />
  <xsl:variable name="statistics_count" select="count(/importlog/statistics/counts/entry)" />

  <xsl:template match="importlog">

    <!-- Index chapter -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">

      <tr class="lightred">
        <td colspan="2">
          <b>
            <xsl:copy-of select="$exceptions_count" />
            Errors
          </b>
        </td>
      </tr>
      <tr class="lightyellow">
        <td colspan="2">
          <b>
            <xsl:copy-of select="$warnings_count" />
            Warnings
          </b>
        </td>
      </tr>

      <!-- exceptions -->
      <xsl:for-each select="/importlog/exception[generate-id(.)=generate-id(key('list_exceptions1', concat(@class,'|',@msg1)))]">
        <xsl:sort />
        <tr>
          <td class="red" width="30%">
            <xsl:value-of select="count(key('list_exceptions1',concat(@class,'|',@msg1)))" />
            x
            <xsl:value-of select="@class" />
            <br />
            <xsl:if test="@msg1 != 'null'">
              <b>
                <xsl:value-of select="@msg1" />
              </b>
            </xsl:if>
          </td>
          <td class="lightred">
            <xsl:for-each select="key('list_exceptions1',concat(@class,'|',@msg1))">
              <xsl:sort />
              <xsl:for-each select="current()[generate-id(.)=generate-id(key('list_exceptions2', concat(@class,'|',@msg1,'|',@msg2)))]">
                <xsl:sort />
                <xsl:if test="position() = 1">
                  <xsl:if test="@msg2 != 'null'">
                    <b class="red">
                      <xsl:value-of select="@msg2" />
                    </b>
                  </xsl:if>
                  <em> in </em>
                </xsl:if>
                <xsl:for-each select="key('list_exceptions2',concat(@class,'|',@msg1,'|',@msg2))">
                  <xsl:sort />
                  <xsl:if test="position() &gt; 1">, </xsl:if>
                  <xsl:variable name="popup_id" select="generate-id()"/> 
                  <div class="popup" id="{$popup_id}">
                    <a style="float: right" href="javascript:toggleVisible('{$popup_id}')">Close</a>
                    <b><xsl:call-template name="refs" /></b><br/>
                    <span class="small">
                    <b>File:</b>:
                    <xsl:value-of select="position/@file" /><br/> 
                    <b>Line:</b>:
                    <xsl:value-of select="position/@line" /><br/>
                    <b>Offset:</b>:
                    <xsl:value-of select="position/@offset" /><br/>
                    </span>
                    <b>Stacktrace:</b><br/>
                    <div class="stacktrace">
                    <xsl:value-of select="stacktrace" />
                    </div>
                  </div>
                  <a class="hiddenlink" href="javascript:toggleVisible('{$popup_id}')">
                    <xsl:call-template name="refs" />
                  </a>
                </xsl:for-each>
                <br />
              </xsl:for-each>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:for-each>

      <!-- warnings -->
      <xsl:for-each select="/importlog/warning[generate-id(.)=generate-id(key('list_warnings1', @msg1))]">
        <xsl:sort select="@msg1" />
        <tr>
          <td class="yellow" width="30%">
            <xsl:value-of select="count(key('list_warnings1',@msg1))" />
            x
            <b>
              <xsl:value-of select="@msg1" />
            </b>
          </td>
          <td class="lightyellow">
            <xsl:for-each select="key('list_warnings1',@msg1)">
              <xsl:sort select="@msg1" />
              <xsl:for-each select="current()[generate-id(.)=generate-id(key('list_warnings2', concat(@msg1,'|',@msg2)))]">
                <xsl:sort />
                <xsl:if test="position() = 1">
                  <xsl:if test="@msg2 != 'null'">
                    <b class="yellow">
                      <xsl:value-of select="@msg2" />
                    </b>
                  </xsl:if>
                  <em> in </em>
                </xsl:if>
                <xsl:for-each select="key('list_warnings2',concat(@msg1,'|',@msg2))">
                  <xsl:sort />
                  <xsl:if test="position() &gt; 1">, </xsl:if>
                  <xsl:variable name="popup_id" select="generate-id()"/> 
                  <div class="popup" id="{$popup_id}">
                    <a style="float: right" href="javascript:toggleVisible('{$popup_id}')">Close</a>
                    <b><xsl:call-template name="refs" /></b><br/>
                    <span class="small">
                    <b>File:</b>:
                    <xsl:value-of select="position/@file" /><br/> 
                    <b>Line:</b>:
                    <xsl:value-of select="position/@line" /><br/> 
                    <b>Offset:</b>:
                    <xsl:value-of select="position/@offset" /><br/>
                    </span>
                  </div>
                  <a class="hiddenlink" href="javascript:toggleVisible('{$popup_id}')">
                    <xsl:call-template name="refs" />
                  </a>
                </xsl:for-each>
                <br />
              </xsl:for-each>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:for-each>

 
 
      <!-- statistics -->
      <xsl:for-each select="/importlog/statistics/counts/level1">
        <xsl:sort select="@key" />
        <tr>
          <td class="green" width="30%">
            <b><xsl:value-of select="@key" /></b><br/>
            count=<xsl:value-of select="count(./level2)" /><br/>
            sum=<xsl:value-of select="sum(./level2/@count)" /><br/>
          </td>
          <td class="lightgreen">
          <xsl:for-each select="level2">
            <xsl:sort select="@count" data-type="number" order="descending" />
            <b class="green">
              <xsl:value-of select="@count" />
              x
              <xsl:value-of select="@key" />
            </b>
            <em> in </em>
            <xsl:call-template name="refs" />
            <br />
          </xsl:for-each>
          </td>
        </tr>
    </xsl:for-each>

    </table>

  </xsl:template>


  <!--
    ***********************************************************************************************************************
    Exceptions
    ***********************************************************************************************************************
  -->

  <xsl:template match="exception">

    <a>
      <xsl:attribute name="name"><xsl:value-of select="concat('exception_', position())" />
            </xsl:attribute>
      <hr></hr>
      <!--      <h4><xsl:value-of select="@message"/></h4> -->
    </a>

    <!-- navigation -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <tr class="red">
        <td width="1">
          <xsl:value-of select="concat(position(), '/', $exceptions_count)" />
        </td>
        <td width="1">
          <a>
            <xsl:attribute name="href"><xsl:value-of select="concat('#list_exception_', position())" />
                        </xsl:attribute>
            list
          </a>
        </td>
        <xsl:choose>
          <xsl:when test="position() &gt; 1">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#exception_', position()-1)" />
                                </xsl:attribute>
                &lt;&lt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&lt;&lt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="position() &lt; $exceptions_count">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#exception_', position()+1)" />
                                </xsl:attribute>
                &gt;&gt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&gt;&gt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <td>
          <b>
            <xsl:value-of select="concat(@class, ' : ', @msg1, ' : ', @msg2)" />
          </b>
        </td>
      </tr>
    </table>

    <table class="lightred" border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <xsl:apply-templates select="refs" />
      <xsl:apply-templates select="position" />
      <xsl:apply-templates select="stacktrace" />
    </table>

  </xsl:template>


  <!--
    ***********************************************************************************************************************
    Warnings
    ***********************************************************************************************************************
  -->

  <xsl:template match="warning">

    <a>
      <xsl:attribute name="name"><xsl:value-of select="concat('warning_', position())" />
            </xsl:attribute>
      <hr></hr>
      <!--      <h4><xsl:value-of select="@message"/></h4> -->
    </a>

    <!-- navigation -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <tr class="yellow">
        <td width="1">
          <xsl:value-of select="concat(position(), '/', $warnings_count)" />
        </td>
        <td width="1">
          <a>
            <xsl:attribute name="href"><xsl:value-of select="concat('#list_warning_', position())" />
                        </xsl:attribute>
            list
          </a>
        </td>
        <xsl:choose>
          <xsl:when test="position() &gt; 1">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#warning_', position()-1)" />
                                </xsl:attribute>
                &lt;&lt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&lt;&lt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="position() &lt; $warnings_count">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#warning_', position()+1)" />
                                </xsl:attribute>
                &gt;&gt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&gt;&gt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <td>
          <b>
            <xsl:value-of select="@message" />
          </b>
        </td>
      </tr>
    </table>

    <table class="lightyellow" border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <xsl:apply-templates select="refs" />
      <xsl:apply-templates select="position" />
    </table>

  </xsl:template>



  <!--
    ***********************************************************************************************************************
    Statistics
    ***********************************************************************************************************************
  -->

  <xsl:template match="statistics/counts/entry">

    <a>
      <xsl:attribute name="name">
            <xsl:value-of select="concat('stats_counts_', position())" />
        </xsl:attribute>
      <hr></hr>
      <!--      <h4><xsl:value-of select="@message"/></h4> -->
    </a>

    <!-- navigation -->
    <table border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <tr class="green">
        <td width="1">
          <a>
            <xsl:attribute name="href"><xsl:value-of select="concat('#list_stats_counts_', position())" />
                        </xsl:attribute>
            list
          </a>
        </td>
        <xsl:choose>
          <xsl:when test="position() &gt; 1">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#stats_counts_', position()-1)" />
                                </xsl:attribute>
                &lt;&lt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&lt;&lt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
          <xsl:when test="position() &lt; $statistics_count">
            <td width="1">
              <a>
                <xsl:attribute name="href"><xsl:value-of select="concat('#stats_counts_', position()+1)" />
                                </xsl:attribute>
                &gt;&gt;
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td width="1">&gt;&gt;</td>
          </xsl:otherwise>
        </xsl:choose>
        <td width="1">
          <xsl:value-of select="@count" />
        </td>
        <td>
          <b>
            <xsl:value-of select="@key" />
          </b>
        </td>
      </tr>
    </table>

    <table class="lightgreen" border="1" cellspacing="2" cellpadding="3" width="100%" style="font-size:80%">
      <xsl:apply-templates select="refs" />
    </table>

  </xsl:template>



  <!--
    ***********************************************************************************************************************
    XForms shared by exceptions, warnings and statistics
    ***********************************************************************************************************************
  -->

  <xsl:template match="position">
    <tr>
      <td width="1">File</td>
      <td>
        <xsl:value-of select="@file" />
        zip=
        <xsl:value-of select="@zip" />
        line=
        <xsl:value-of select="@line" />
        offset=
        <xsl:value-of select="@offset" />
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="stacktrace">
    <tr>
      <td width="1">Stacktrace</td>
      <td>
        <pre class="trace">
          <xsl:value-of select="." />
        </pre>
      </td>
    </tr>
  </xsl:template>



  <!--
    ***********************************************************************************************************************
    FormatRefs
    ***********************************************************************************************************************
  -->

  <xsl:template name="refs">
    <xsl:apply-templates select="endfrefs" />
    <xsl:apply-templates select="nubaserefs" />
    <xsl:apply-templates select="gendfrefs" />
    <xsl:apply-templates select="interrefs" />
    <xsl:apply-templates select="exforrefs" />
    <xsl:apply-templates select="cindarefs" />
    <xsl:apply-templates select="boxerrefs" />
    <xsl:apply-templates select="errorrrefs" />
  </xsl:template>

  <xsl:template match="nubaserefs">
    <xsl:variable name="element-z" select="@z"/><xsl:variable name="element-label" select="$elements[@z=$element-z]/@s"/>
    <span class="ref">
    <b>
    <xsl:choose><xsl:when test="not(normalize-space($element-label))"><xsl:value-of select="$element-z"/></xsl:when><xsl:otherwise><xsl:value-of select="$element-label"/></xsl:otherwise></xsl:choose>
    <xsl:value-of select="@a" />
    <xsl:if test="@state != 0">m<xsl:value-of select="@state" /></xsl:if>
    </b>
    </span>
  </xsl:template>

  <xsl:template match="endfrefs">
    <xsl:variable name="element-z" select="@z"/><xsl:variable name="element-label" select="$elements[@z=$element-z]/@s"/>
    <span class="ref">
    <b>
    <xsl:choose><xsl:when test="not(normalize-space($element-label))"><xsl:value-of select="$element-z"/></xsl:when><xsl:otherwise><xsl:value-of select="$element-label"/></xsl:otherwise></xsl:choose>
    <xsl:value-of select="@a" />
    <xsl:if test="@state != 0">m<xsl:value-of select="@state" /></xsl:if>
    MF<xsl:value-of select="@mf" />
    MT<xsl:value-of select="@mt" />
    MAT<xsl:value-of select="@mat" />
    </b>
    <i>
    NLIB,NVER=<xsl:value-of select="@nlib_nver" />
    NSUB=<xsl:value-of select="@nsub" />
    NMOD=<xsl:value-of select="@nmod" />
    </i>
    </span>
  </xsl:template>

  <xsl:template match="gendfrefs">
    <xsl:variable name="element-z" select="@z"/><xsl:variable name="element-label" select="$elements[@z=$element-z]/@s"/>
    <span class="ref">
    <b>
    <xsl:choose><xsl:when test="not(normalize-space($element-label))"><xsl:value-of select="$element-z"/></xsl:when><xsl:otherwise><xsl:value-of select="$element-label"/></xsl:otherwise></xsl:choose>
    <xsl:value-of select="@a" />
    <xsl:if test="@state != 0">m<xsl:value-of select="@state" /></xsl:if>
    MF<xsl:value-of select="@mf" />
    MT<xsl:value-of select="@mt" />
    MAT<xsl:value-of select="@mat" />
    </b>
    TEMP=<xsl:value-of select="@temp" />
    </span>
  </xsl:template>
  
  <xsl:template match="errorrrefs">
    <xsl:variable name="element-z" select="@z"/><xsl:variable name="element-label" select="$elements[@z=$element-z]/@s"/>
    <span class="ref">
    <b>
    <xsl:choose><xsl:when test="not(normalize-space($element-label))"><xsl:value-of select="$element-z"/></xsl:when><xsl:otherwise><xsl:value-of select="$element-label"/></xsl:otherwise></xsl:choose>
    <xsl:value-of select="@a" />
    <xsl:if test="@state != 0">m<xsl:value-of select="@state" /></xsl:if>
    MF<xsl:value-of select="@mf" />
    MT<xsl:value-of select="@mt" />
    MAT<xsl:value-of select="@mat" />
    </b>
    </span>
  </xsl:template>

  <xsl:template match="boxerrefs">
    ITYPE=
    <xsl:value-of select="@itype" />
    MAT=
    <xsl:value-of select="@mat" />
    MT=
    <xsl:value-of select="@mt" />
    MAT1=
    <xsl:value-of select="@mat1" />
    MT1=
    <xsl:value-of select="@mt1" />
  </xsl:template>

  <xsl:template match="interrefs">
    Z=
    <xsl:value-of select="@z" />
    A=
    <xsl:value-of select="@a" />
    liso=
    <xsl:value-of select="@liso" />
    MT=
    <xsl:value-of select="@mt" />
    library=
    <xsl:value-of select="@library" />
  </xsl:template>

  <xsl:template match="exforrefs">
    <xsl:value-of select="concat(@accession_number, '.', format-number(@subaccession_number, '000'))" />
  </xsl:template>

  <xsl:template match="cindarefs">
    <xsl:value-of select="concat(@block_number, '-', @sequence)" />
  </xsl:template>

  <!--
    ***********************************************************************************************************************
    Elements symbols
    ***********************************************************************************************************************
  -->

  <j:elements>
    <e z="0" s="n"/><e z="1" s="H"/><e z="2" s="He"/><e z="3" s="Li"/><e z="4" s="Be"/>
    <e z="5" s="B"/><e z="6" s="C"/><e z="7" s="N"/><e z="8" s="O"/><e z="9" s="F"/>
    <e z="10" s="Ne"/><e z="11" s="Na"/><e z="12" s="Mg"/><e z="13" s="Al"/><e z="14" s="Si"/>
    <e z="15" s="P"/><e z="16" s="S"/><e z="17" s="Cl"/><e z="18" s="Ar"/><e z="19" s="K"/>
    <e z="20" s="Ca"/><e z="21" s="Sc"/><e z="22" s="Ti"/><e z="23" s="V"/><e z="24" s="Cr"/>
    <e z="25" s="Mn"/><e z="26" s="Fe"/><e z="27" s="Co"/><e z="28" s="Ni"/><e z="29" s="Cu"/>
    <e z="30" s="Zn"/><e z="31" s="Ga"/><e z="32" s="Ge"/><e z="33" s="As"/><e z="34" s="Se"/>
    <e z="35" s="Br"/><e z="36" s="Kr"/><e z="37" s="Rb"/><e z="38" s="Sr"/><e z="39" s="Y"/>
    <e z="40" s="Zr"/><e z="41" s="Nb"/><e z="42" s="Mo"/><e z="43" s="Tc"/><e z="44" s="Ru"/>
    <e z="45" s="Rh"/><e z="46" s="Pd"/><e z="47" s="Ag"/><e z="48" s="Cd"/><e z="49" s="In"/>
    <e z="50" s="Sn"/><e z="51" s="Sb"/><e z="52" s="Te"/><e z="53" s="I"/><e z="54" s="Xe"/>
    <e z="55" s="Cs"/><e z="56" s="Ba"/><e z="57" s="La"/><e z="58" s="Ce"/><e z="59" s="Pr"/>
    <e z="60" s="Nd"/><e z="61" s="Pm"/><e z="62" s="Sm"/><e z="63" s="Eu"/><e z="64" s="Gd"/>
    <e z="65" s="Tb"/><e z="66" s="Dy"/><e z="67" s="Ho"/><e z="68" s="Er"/><e z="69" s="Tm"/>
    <e z="70" s="Yb"/><e z="71" s="Lu"/><e z="72" s="Hf"/><e z="73" s="Ta"/><e z="74" s="W"/>
    <e z="75" s="Re"/><e z="76" s="Os"/><e z="77" s="Ir"/><e z="78" s="Pt"/><e z="79" s="Au"/>
    <e z="80" s="Hg"/><e z="81" s="Tl"/><e z="82" s="Pb"/><e z="83" s="Bi"/><e z="84" s="Po"/>
    <e z="85" s="At"/><e z="86" s="Rn"/><e z="87" s="Fr"/><e z="88" s="Ra"/><e z="89" s="Ac"/>
    <e z="90" s="Th"/><e z="91" s="Pa"/><e z="92" s="U"/><e z="93" s="Np"/><e z="94" s="Pu"/>
    <e z="95" s="Am"/><e z="96" s="Cm"/><e z="97" s="Bk"/><e z="98" s="Cf"/><e z="99" s="Es"/>
    <e z="100" s="Fm"/><e z="101" s="Md"/><e z="102" s="No"/><e z="103" s="Lr"/><e z="104" s="Rf"/>
    <e z="105" s="Db"/><e z="106" s="Sg"/><e z="107" s="Bh"/><e z="108" s="Hs"/><e z="109" s="Mt"/>
    <e z="110" s="Ds"/><e z="111" s="Rg"/><e z="112" s="Cn"/><e z="113" s="Nh"/><e z="114" s="Fl"/>
    <e z="115" s="Mc"/><e z="116" s="Lv"/><e z="117" s="Ts"/><e z="118" s="Og"/>
  </j:elements>
  <xsl:variable name="elements" select="document('')/xsl:stylesheet/j:elements/e"/>

</xsl:stylesheet>
