<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="1.0">
    <xsl:output 
        method="html" 
        indent="yes" 
        encoding="UTF-8" 
        doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
        doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

	<!--
		JANIS Import Log
	-->

	<xsl:decimal-format decimal-separator="." grouping-separator="," />

	<xsl:key name="list_exceptions1" match="exception"
		use="concat(@class,'|',@msg1)" />
	<xsl:key name="list_exceptions2" match="exception"
		use="concat(@class,'|',@msg1,'|',@msg2)" />
	<xsl:key name="list_warnings1" match="warning" use="@msg1" />
	<xsl:key name="list_warnings2" match="warning"
		use="concat(@msg1,'|',@msg2)" />

	<xsl:template match="/">
		<html>
			<head>
                <title>JANIS - TRANS Check Log</title>
				<style type="text/css">
                    body {
                        margin: 0; font:normal 100%
                        arial,helvetica,sanserif; background-color:#FFFFFF;
                        color:#000000; } 
                    
                    .r { background: #ff5555; } 
                    .lr { background: #ffcccc; } 
                    .y{ background: #ffff55; } 
                    .ly { background: #ffffcc; } 
                    .g { background: #55ff55; } 
                    .lg { background: #ccffcc; }

                    th, td { text-align: left; vertical-align: top; } 
                    th { background: #ccc; color: black; } 
                    table, th, td { border: none }

                    .h td { 
                        font:bold 120% arial,helvetica,sanserif; 
                        text-align: center; background: #525D76; color:
                        white; text-decoration: none; padding: 6px;
                        margin-right: 2px; margin-left: 2px; margin-top: 0;
                        margin-bottom: 0; }
				</style>
			</head>
			<body>
				<table border="0" width="100%">
					<tr>
						<td>
							<hr noshade="noshade" size="1" />
						</td>
					</tr>
				</table>

				<!-- title -->
				<table border="1" cellspacing="0" cellpadding="0"
					width="100%" style="font-size:120%">
					<tr class="h">
                        <td>JANIS Import Log<br />
                        <span style="font-size:50%"><xsl:value-of select="/importlog/@timestamp" /></span></td>
					</tr>
				</table>

				<xsl:apply-templates select="importlog" />

				<!-- footer -->
				<table width="100%">
					<tr>
						<td>
							<hr noshade="noshade" size="1" />
						</td>
					</tr>
					<tr>
						<td>
							<div align="center">
								<font color="#525D76" size="-1">
                                    <em>JANIS Import Log</em> - 
                                    <xsl:value-of select="/importlog/@timestamp" />
								</font>
							</div>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>


	<xsl:variable name="warnings_count"
		select="count(/importlog/warning)" />
	<xsl:variable name="exceptions_count"
		select="count(/importlog/exception)" />
	<xsl:variable name="statistics_count"
		select="count(/importlog/statistics/counts/entry)" />

	<xsl:template match="importlog">

		<!-- Index chapter -->
		<table border="1" cellspacing="2" cellpadding="3" width="100%"
			style="font-size:80%">

			<tr class="lr">
				<td colspan="3">
					<b>
						<xsl:copy-of select="$exceptions_count" />
						Errors
					</b>
				</td>
			</tr>
			<tr class="ly">
				<td colspan="3">
					<b>
						<xsl:copy-of select="$warnings_count" />
						Warnings
					</b>
				</td>
			</tr>
            <tr>
                <td width="5%">Subent</td>
                <td width="30%">Message</td>
                <td>Details <em>line number</em></td>
            </tr>

			<!-- exceptions -->
			<xsl:apply-templates select="(exception|warning)" />

		</table>

	</xsl:template>


	<!--
		***********************************************************************************************************************
		Exceptions
		***********************************************************************************************************************
	-->

	<xsl:template match="exception">

		<tr>
            <td class="r">
                <xsl:apply-templates select="exforrefs" />
            </td>		      
			<td class="r">
				<xsl:value-of select="@class" />
				<br />
				<xsl:if test="@msg1 != 'null'">
					<b>
						<xsl:value-of select="@msg1" />
					</b>
				</xsl:if>
			</td>
			<td class="lr">
				<xsl:if test="@msg2 != 'null'">
					<b>
						<xsl:value-of select="@msg2" />
					</b>
				</xsl:if>
				<em> line <xsl:value-of select="position/@line" /></em>
			</td>
		</tr>

	</xsl:template>


	<!--
		***********************************************************************************************************************
		Warnings
		***********************************************************************************************************************
	-->

	<xsl:template match="warning">

		<tr>
            <td class="y">
                <xsl:apply-templates select="exforrefs" />
            </td>             
			<td class="y">
				<xsl:if test="@msg1 != 'null'">
					<b>
						<xsl:value-of select="@msg1" />
					</b>
				</xsl:if>
			</td>
			<td class="ly">
				<xsl:if test="@msg2 != 'null'">
					<b>
						<xsl:value-of select="@msg2" />
					</b>
				</xsl:if>
                <em> line <xsl:value-of select="position/@line" /></em>
			</td>
		</tr>

	</xsl:template>





	<xsl:template match="exforrefs">
		<xsl:value-of
			select="concat(@accession_number, '.', format-number(@subaccession_number, '000'))" />
	</xsl:template>

</xsl:stylesheet>
